<?php
/**
 * Plugin Name: Instant AI Guru Chat Widget
 * Plugin URI: https://instantAIguru.com
 * Description: Adds the Instant AI Guru Chat Widget to your WordPress site, enabling an AI-powered assistant for your users.
 * Version: 1.4
 * Author: Instant AI Guru
 * License: GPLv2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 */

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

// Default widget script URL
define('INSTANT_AI_GURU_DEFAULT_URL', 'https://widget.instantaiguru.com/chat-widget.min.js?v=1.01');

add_action('wp_enqueue_scripts', 'instant_ai_guru_enque_widget');
function instant_ai_guru_enque_widget() {
    // Get the custom URL and colors from settings or use the defaults
    $script_url = get_option('instant_ai_guru_script_url', INSTANT_AI_GURU_DEFAULT_URL);
    $background_color = get_option('instant_ai_guru_background_color', '#3f51b5');
    $text_color = get_option('instant_ai_guru_text_color', '#ffffff');
    $header_text = get_option('instant_ai_guru_header_text', 'Ask our Guru');
    // Get the domain name
    $domain = $_SERVER['HTTP_HOST'];
    // Remove www. from the domain name if present
    if (strpos($domain, 'www.') === 0) {
        $domain = substr($domain, 4);
    }
    
    $welcome_message = get_option('instant_ai_guru_welcome_message', 'Hello! How can I help you with any question about $domain?');
    $welcome_message = str_replace('$domain', $domain, $welcome_message);
    $display_name = get_option('instant_ai_guru_display_name', 'Web Visitor');
    // Output the color variables as inline JavaScript
    $inline_script = "
        window.iAIgW_theme_background_color = " . json_encode($background_color) . ";
        window.iAIgW_theme_color = " . json_encode($text_color) . ";
        window.iAIgW_header_text = " . json_encode($header_text) . ";
        window.instantAIguru = {
            welcome_message: " . json_encode($welcome_message) . ",
            display_name: " . json_encode($display_name) . ",
            domain: " . json_encode($domain) . "
        };
    ";

    // Add the inline script before enqueueing the widget script
    wp_register_script('instant-ai-guru-widget', $script_url, [], '1.2', true);
    wp_add_inline_script('instant-ai-guru-widget', $inline_script, 'before');
    wp_enqueue_script('instant-ai-guru-widget', $script_url, [], '1.2', true);
}


// Add the defer attribute to the chat widget script
add_filter('script_loader_tag', 'instant_ai_guru_add_defer_attribute', 10, 3);
function instant_ai_guru_add_defer_attribute($tag, $handle, $src) {
    if ($handle === 'instant-ai-guru-widget') {
        return str_replace(' src', ' defer src', $tag);
    }
    return $tag;
}

// Add a settings page for the plugin
add_action('admin_menu', 'instant_ai_guru_add_settings_page');
function instant_ai_guru_add_settings_page() {
    add_options_page(
        'Instant AI Guru Settings', // Page title
        'Instant AI Guru',          // Menu title
        'manage_options',           // Capability
        'instant-ai-guru-settings', // Menu slug
        'instant_ai_guru_render_settings_page' // Callback function
    );
}

// Enqueue WordPress Color Picker assets for the settings page
add_action('admin_enqueue_scripts', 'instant_ai_guru_enqueue_color_picker');
function instant_ai_guru_enqueue_color_picker($hook) {
    // Only enqueue on the plugin settings page
    if ($hook === 'settings_page_instant-ai-guru-settings') {
        wp_enqueue_style('wp-color-picker'); // Color Picker styles
        wp_enqueue_script('instant-ai-guru-color-picker', plugins_url('color-picker.js', __FILE__), ['wp-color-picker'], '1.0.0', true);
    }
}

// Render the settings page
function instant_ai_guru_render_settings_page() {
    $domain = $_SERVER['HTTP_HOST'];
    // Remove www. from the domain name if present
    if (strpos($domain, 'www.') === 0) {
        $domain = substr($domain, 4);
    }

    if (isset($_SERVER['REQUEST_METHOD']) && $_SERVER['REQUEST_METHOD'] === 'POST') {
        if (isset($_POST['instant_ai_guru_settings_nonce'])) {
            $nonce = sanitize_text_field(wp_unslash($_POST['instant_ai_guru_settings_nonce']));
            if (!wp_verify_nonce($nonce, 'instant_ai_guru_settings_nonce_action')) {
                wp_die('Security check failed. Please try again.');
            }
        } else {
            wp_die('Security check failed. Please try again.');
        }

        $custom_url = isset($_POST['instant_ai_guru_script_url']) ? esc_url_raw(wp_unslash($_POST['instant_ai_guru_script_url'])) : INSTANT_AI_GURU_DEFAULT_URL;
        update_option('instant_ai_guru_script_url', $custom_url);

        $background_color = isset($_POST['instant_ai_guru_background_color']) ? sanitize_hex_color(wp_unslash($_POST['instant_ai_guru_background_color'])) : '#3f51b5';
        update_option('instant_ai_guru_background_color', $background_color);

        $text_color = isset($_POST['instant_ai_guru_text_color']) ? sanitize_hex_color(wp_unslash($_POST['instant_ai_guru_text_color'])) : '#ffffff';
        update_option('instant_ai_guru_text_color', $text_color);

        $header_text = isset($_POST['instant_ai_guru_header_text']) ? sanitize_text_field(wp_unslash($_POST['instant_ai_guru_header_text'])) : 'Ask our Guru';
        update_option('instant_ai_guru_header_text', $header_text);

        $welcome_message = isset($_POST['instant_ai_guru_welcome_message']) ? sanitize_text_field(wp_unslash($_POST['instant_ai_guru_welcome_message'])) : 'Hello! How can I help you with any question about $domain?';
        update_option('instant_ai_guru_welcome_message', $welcome_message);

        $display_name = isset($_POST['instant_ai_guru_display_name']) ? sanitize_text_field(wp_unslash($_POST['instant_ai_guru_display_name'])) : 'Web Visitor';
        update_option('instant_ai_guru_display_name', $display_name);

        echo '<div class="updated"><p>Settings saved.</p></div>';
    }

    // Get the current URL setting
    $current_url = get_option('instant_ai_guru_script_url', INSTANT_AI_GURU_DEFAULT_URL);
    $background_color = get_option('instant_ai_guru_background_color', '#3f51b5');
    $text_color = get_option('instant_ai_guru_text_color', '#ffffff');
    $header_text = get_option('instant_ai_guru_header_text', 'Ask our Guru');
    $welcome_message = get_option('instant_ai_guru_welcome_message', 'Hello! How can I help you with any question about $domain?');
    $display_name = get_option('instant_ai_guru_display_name', 'Web Visitor');

    ?>
    <div class="wrap">
        <h1>Instant AI Guru Settings</h1>
        <form method="post" action="">
            <?php wp_nonce_field('instant_ai_guru_settings_nonce_action', 'instant_ai_guru_settings_nonce'); ?>
            <table class="form-table">
                <tr>
                    <th scope="row">
                        <label for="instant_ai_guru_script_url">Widget Script URL</label>
                    </th>
                    <td>
                        <input type="url" id="instant_ai_guru_script_url" name="instant_ai_guru_script_url" value="<?php echo esc_attr($current_url); ?>" class="regular-text" />
                        <p class="description">Enter the custom URL for the Instant AI Guru widget. Leave blank to use the default URL.</p>
                    </td>
                </tr>
                <tr>
                <th scope="row">
                        <label for="instant_ai_guru_background_color">Background Color</label>
                    </th>
                    <td>
                        <input type="text" id="instant_ai_guru_background_color" name="instant_ai_guru_background_color" value="<?php echo esc_attr($background_color); ?>" class="color-picker" />
                        <p class="description">Select the background color for the chat widget.</p>
                    </td>
                </tr>
                <tr>
                    <th scope="row">
                        <label for="instant_ai_guru_text_color">Text Color</label>
                    </th>
                    <td>
                        <input type="text" id="instant_ai_guru_text_color" name="instant_ai_guru_text_color" value="<?php echo esc_attr($text_color); ?>" class="color-picker" />
                        <p class="description">Select the text color for the chat widget.</p>
                    </td>
                </tr>
                <tr>
                    <th scope="row">
                        <label for="instant_ai_guru_header_text">Header Text</label>
                    </th>
                    <td>
                        <input type="text" id="instant_ai_guru_header_text" name="instant_ai_guru_header_text" value="<?php echo esc_attr($header_text); ?>" class="regular-text" />
                        <p class="description">Enter the text to display in the chat widget header.</p>
                    </td>
                </tr>
                <tr>
                    <th scope="row">
                        <label for="instant_ai_guru_welcome_message">Welcome Message</label>
                    </th>
                    <td>
                        <input type="text" id="instant_ai_guru_welcome_message" name="instant_ai_guru_welcome_message" value="<?php echo esc_attr($welcome_message); ?>" class="regular-text" />
                        <p class="description">Enter the welcome message for the chat widget. Use $domain as a placeholder for the domain name.</p>
                    </td>
                </tr>
                <tr>
                    <th scope="row">
                        <label for="instant_ai_guru_display_name">Chat User Name</label>
                    </th>
                    <td>
                        <input type="text" id="instant_ai_guru_display_name" name="instant_ai_guru_display_name" value="<?php echo esc_attr($display_name); ?>" class="regular-text" />
                        <p class="description">Enter the display name for the chat widget.</p>
                    </td>
                </tr>
            </table>
            <?php submit_button('Save Changes'); ?>
        </form>
    </div>
    <?php
}

// Add a link to the settings page in the plugins list
add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'instant_ai_guru_add_settings_link');
function instant_ai_guru_add_settings_link($links) {
    $settings_link = '<a href="options-general.php?page=instant-ai-guru-settings">Settings</a>';
    array_unshift($links, $settings_link);
    return $links;
}
?>
